@@ -30,7 +30,6 @@
 #' @return No returned value.
 #' @family plotting functions
 #' @examples
-#' data(bot)
 #' b <- bot[1]
 #' coo_plot(b)
 #' coo_plot(bot[2], plot.new=FALSE) # equivalent to coo_draw(bot[2])
@@ -108,8 +107,8 @@ coo_plot.default <- function(coo, xlim, ylim, border = "#333333",
       points(coo, pch = pch, cex = cex, col = border)
     }
     if (first.point) {
-        angle <- atan2(coo[2, 2] - coo[1, 2], coo[2, 1] - coo[1, 1]) * (180 / pi) - 90
-        text(coo[1, 1], coo[1, 2], labels = "^", cex=0.5, srt=angle)
+      angle <- atan2(coo[2, 2] - coo[1, 2], coo[2, 1] - coo[1, 1]) * (180 / pi) - 90
+      text(coo[1, 1], coo[1, 2], labels = "^", cex=0.5, srt=angle)
     }
     if (centroid) {
       cent <- coo_centpos(coo)
@@ -128,7 +127,6 @@ coo_plot.default <- function(coo, xlim, ylim, border = "#333333",
 #' @param ... optional parameters for \link{coo_plot}
 #' @family plotting functions
 #' @examples
-#' data(bot)
 #' b1 <- bot[4]
 #' b2 <- bot[5]
 #' coo_plot(b1)
@@ -166,7 +164,6 @@ coo_draw_rads <- function(coo, ...){
 #' @param ... optional parameters to fed \link{points} and \link{segments}.
 #' @family plotting functions
 #' @examples
-#' data(olea)
 #' coo_lolli(coo_sample(olea[3], 50), coo_sample(olea[6], 50))
 #' title("A nice title !")
 #' @export
@@ -195,7 +192,6 @@ coo_lolli <- function(coo1, coo2,
 #' @param ... optional parameters to fed \link{arrows}.
 #' @family plotting functions
 #' @examples
-#' data(olea)
 #' coo_arrows(coo_sample(olea[3], 50), coo_sample(olea[6], 50))
 #' title("Hi there !")
 #' @export
@@ -220,11 +216,10 @@ coo_arrows <- function(coo1, coo2,
 #' @param dev numeric a vector of distances or anythinh relevant
 #' @param  palette the color palette to use or any palette
 #' @param normalize logical whether to normalize (TRUE by default) distances
-#' @param ... other paremeters to fed segments, eg lwd (see examples)
+#' @param ... other parameters to fed segments, eg lwd (see examples)
 #' @return nothing
 #' @family plotting functions
 #' @examples
-#' data(bot)
 #' ms <- mshapes(efourier(bot , 10), "type")
 #' b <- ms$shp$beer
 #' w <- ms$shp$whisky
@@ -243,11 +238,11 @@ coo_arrows <- function(coo1, coo2,
 #'
 #' #If you want linewidth rather than color
 #' coo_plot(m, plot=FALSE)
-#' coo_ruban(m, d, palette=col_black, lwd=.normalize(d)*10)
+#' coo_ruban(m, d, palette=col_black)
 #' @family plotting functions
 #' @export
 coo_ruban <- function(coo, dev,
-                     palette=col_heat, normalize=TRUE, ...){
+                      palette=col_heat, normalize=TRUE, ...){
   if (nrow(coo) != length(dev))
     stop("'coo' and 'dev' must have the same number of rows")
   if(normalize) dev <- .normalize(dev)
@@ -270,7 +265,7 @@ coo_ruban <- function(coo, dev,
 #' @param coo.list A \code{list} of coordinates
 #' @param dim A \code{vector} of the form \code{(nb.row, nb.cols)} to specify
 #' the panel display. If missing, shapes are arranged in a square.
-#' @param byrow \code{logical}. Whether to succesive shape by row or by col.
+#' @param byrow \code{logical}. Whether to draw successive shape by row or by col.
 #' @param fromtop \code{logical}. Whether to display shapes from the top of the
 #' plotting region.
 #' @param cols A \code{vector} of colors to fill shapes.
@@ -289,8 +284,8 @@ coo_ruban <- function(coo, dev,
 #' @family plotting functions
 #' @export
 coo_listpanel <- function(coo.list, dim, byrow = TRUE, fromtop = TRUE,
-                           cols, borders, poly = TRUE,
-                           points = FALSE, points.pch = 3, points.cex = 0.2, points.col = "#333333", ...) {
+                          cols, borders, poly = TRUE,
+                          points = FALSE, points.pch = 3, points.cex = 0.2, points.col = "#333333", ...) {
   coo.list <- lapply(coo.list, coo_check)
   # if dim is missing, we define a square
   n <- length(coo.list)
@@ -370,7 +365,6 @@ ldk_plot <- function(coo, ...){
 #' @family plotting functions
 #' @family ldk plotters
 #' @examples
-#' data(wings)
 #' coo_plot(wings[1])
 #' ldk_labels(wings[1])
 #' # closer and smaller
@@ -419,7 +413,6 @@ ldk_links <- function(ldk, links, ...) {
 #' @param ax logical whether to draw ellipses axes
 #' @param ax.lty an lty for ellipses axes
 #' @examples
-#' data(wings)
 #' coo_plot(mshapes(wings))
 #' ldk_confell(wings$coo)
 #' @family plotting functions
@@ -455,7 +448,6 @@ ldk_confell <- function(ldk, conf = 0.5, col = "grey40", ell.lty = 1,
 #' @param col a color for drawing the contour lines
 #' @seealso \link{kde2d}, \link{ldk_confell}, \link{ldk_chull}
 #' @examples
-#' data(wings)
 #' coo_plot(mshapes(wings))
 #' ldk_contour(wings$coo)
 #' @family plotting functions
@@ -482,7 +474,6 @@ ldk_contour <- function(ldk, nlevels = 5, grid.nb = 50, col = "grey60") {
 #' @param lty an lty for drawing the convex hulls
 #' @seealso \link{coo_chull}, \link{chull}, \link{ldk_confell}, \link{ldk_contour}
 #' @examples
-#' data(wings)
 #' coo_plot(mshapes(wings))
 #' ldk_chull(wings$coo)
 #' @family plotting functions
@@ -492,7 +483,7 @@ ldk_chull <- function(ldk, col = "grey40", lty = 1) {
   ldk <- ldk_check(ldk)
   nl <- dim(ldk)[1]
   for (i in 1:nl) {
-    ind.i <- chull(ldk[i, 1, ], ldk[i, 2, ])
+    ind.i <- grDevices::chull(ldk[i, 1, ], ldk[i, 2, ])
     coo_draw(coo_close(t(ldk[i, , ind.i])), border = col,
              col = NA, lty = lty, points = FALSE, first.point = FALSE,
              centroid = FALSE)
@@ -513,7 +504,6 @@ ldk_chull <- function(ldk, col = "grey40", lty = 1) {
 #' @examples
 #'
 #' # we load some data
-#' data(bot)
 #' guinness <- coo_sample(bot[9], 100)
 #'
 #' # we calculate the diff between 48 harm and one with 6 harm.
@@ -544,31 +534,31 @@ plot_devsegments <- function(coo, cols, lwd = 1) {
   }
 }
 
-#' Confidence ellipses
-#'
-#' Draw (gaussian) confidence ellipses
-#' @param x numeric values on the x axis
-#' @param y numeric values on the y axis
-#' @param conf the level of confidence
-#' @param nb.pts the number of points to return, to draw the ellipsis
-#' @return a list with $ell coordinates of the ellipse and $seg coordinates
-#' of its vertices
-#' @return a matrix of (x; y) coordinates to draw the ellipsis
-#' @family plotting functions
-#' @examples
-#' x <- rnorm(100, sd=3)
-#' y <- rnorm(100)
-#' plot(x, y, asp=1)
-#' ce095 <- conf_ell(x, y, conf=0.95) # no need for conf arg since it's .95 by default
-#' ce090 <- conf_ell(x, y, conf=0.90)
-#' ce050 <- conf_ell(x, y, conf=0.50)
-#' cols <- col_hot(10)
-#' lines(ce050$ell, col=cols[5]) # you can also coo_close(ce050$ell)
-#' lines(ce090$ell, col=cols[8])
-#' lines(ce095$ell, col=cols[9])
-#' segments(ce095$seg[1, 1], ce095$seg[1, 2], ce095$seg[2, 1], ce095$seg[2, 2])
-#' segments(ce095$seg[3, 1], ce095$seg[3, 2], ce095$seg[4, 1], ce095$seg[4, 2])
-#' @export
+# #' Confidence ellipses
+# #'
+# #' Draw (gaussian) confidence ellipses
+# #' @param x numeric values on the x axis
+# #' @param y numeric values on the y axis
+# #' @param conf the level of confidence
+# #' @param nb.pts the number of points to return, to draw the ellipsis
+# #' @return a list with $ell coordinates of the ellipse and $seg coordinates
+# #' of its vertices
+# #' @return a matrix of (x; y) coordinates to draw the ellipsis
+# #' @family plotting functions
+# #' @examples
+# #' x <- rnorm(100, sd=3)
+# #' y <- rnorm(100)
+# #' plot(x, y, asp=1)
+# #' ce095 <- conf_ell(x, y, conf=0.95) # no need for conf arg since it's .95 by default
+# #' ce090 <- conf_ell(x, y, conf=0.90)
+# #' ce050 <- conf_ell(x, y, conf=0.50)
+# #' cols <- col_hot(10)
+# #' lines(ce050$ell, col=cols[5]) # you can also coo_close(ce050$ell)
+# #' lines(ce090$ell, col=cols[8])
+# #' lines(ce095$ell, col=cols[9])
+# #' segments(ce095$seg[1, 1], ce095$seg[1, 2], ce095$seg[2, 1], ce095$seg[2, 2])
+# #' segments(ce095$seg[3, 1], ce095$seg[3, 2], ce095$seg[4, 1], ce095$seg[4, 2])
+# # #' @export # no need to export this
 conf_ell <- function(x, y, conf = 0.95, nb.pts = 60) {
   if (is.matrix(x)) {
     y <- x[, 2]
@@ -607,10 +597,9 @@ conf_ell <- function(x, y, conf = 0.95, nb.pts = 60) {
 #' @param rm0 logical whether to print zeros
 #' @return a ggplot2 object
 #' @examples
-#' data(olea)
-#' Ntable(olea, "var")
-#' Ntable(olea, "domes", "var")
-#' gg <- Ntable(olea, "domes", "var", rm0 = TRUE)
+#' plot_table(olea, "var")
+#' plot_table(olea, "domes", "var")
+#' gg <- plot_table(olea, "domes", "var", rm0 = TRUE)
 #' gg
 #' library(ggplot2)
 #' gg + coord_equal()
@@ -618,13 +607,13 @@ conf_ell <- function(x, y, conf = 0.95, nb.pts = 60) {
 #' gg + coord_flip()
 #' @family plotting functions
 #' @export
-Ntable <- function(x, fac1, fac2=fac1, rm0 = FALSE){
+plot_table <- function(x, fac1, fac2=fac1, rm0 = FALSE){
   # we check a bit
   if (is.null(x$fac))
-    stop("Ntable must be called on an object with a $fac slot")
+    stop("plot_table must be called on an object with a $fac slot")
   if (missing(fac1))
     stop("'fac1' must be specified")
-  df <- select_(x$fac, fac1, fac2)
+  df <- dplyr::select_(x$fac, fac1, fac2)
   # we return a barplot when a single fac is called (fac1 then)
   if (missing(fac2) | identical(fac1, fac2)) { # | is justified by rm0 after
     gg <- ggplot(df, aes_string(x=fac1)) + geom_bar()
@@ -701,7 +690,7 @@ Ntable <- function(x, fac1, fac2=fac1, rm0 = FALSE){
 #     # Make each plot, in the correct location
 #     for (i in 1:numPlots) {
 #       # Get the i,j matrix positions of the regions that contain this subplot
-#       matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
+#       matchidx <- as.dataa.frame(which(layout == i, arr.ind = TRUE))
 #
 #       print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
 #                                       layout.pos.col = matchidx$col))
@@ -719,11 +708,12 @@ Ntable <- function(x, fac1, fac2=fac1, rm0 = FALSE){
 #' @param coo A list or a matrix of coordinates.
 #' @param method character among \code{c('efourier', 'rfourier', 'tfourier', 'all')}.
 #' \code{'all'} by default
+#' @param shape \code{logical} whether to plot the original shape
 #' @param nb.pts \code{integer}. The number or reference points, sampled
 #' equidistantly along the curvilinear abscissa and added on the oscillo
 #' curves.
+#' @return the plotted values
 #' @examples
-#' data(shapes)
 #' coo_oscillo(shapes[4])
 #' coo_oscillo(shapes[4], 'efourier')
 #' coo_oscillo(shapes[4], 'rfourier')
@@ -732,35 +722,39 @@ Ntable <- function(x, fac1, fac2=fac1, rm0 = FALSE){
 #' coo_oscillo(coo_smooth(shapes[4], 10), 'tfourier')
 #' @seealso exemplifying functions
 #' @export
-coo_oscillo <- function(coo, method = c("efourier", "rfourier",
-                                        "tfourier", "all")[4], nb.pts = 24) {
+coo_oscillo <- function(coo,
+                        method = c("efourier", "rfourier", "tfourier", "all")[4],
+                        shape = TRUE,
+                        nb.pts = 12) {
   # we preapre a couple of things for coming graphics
   labels <- 1:nb.pts
-  sampled <- round(seq(1, nrow(coo), len = nb.pts + 1)[-(nb.pts +
-                                                           1)])
+  sampled <- round(seq(1, nrow(coo), len = nb.pts + 1)[-(nb.pts + 1)])
   coo_lite <- coo[sampled, ]  # equivalent to coo_sample
   # we define a layout
   if (method == "all") {
     layout(matrix(1:4, ncol = 2, byrow = TRUE))
   } else {
-    layout(matrix(1:2, ncol = 2, byrow = TRUE))
+    if (shape)
+      layout(matrix(1:2, ncol = 2, byrow = TRUE))
   }
 
   # the original shape
-  coo_plot(coo, first.point = FALSE)
-  text(coo_lite, labels = labels, cex = 0.7, font = 2)
+  if (shape & method != "all") {
+    coo_plot(coo, first.point = FALSE)
+    text(coo_lite, labels = labels, cex = 0.7, font = 2)
+  }
 
   if (any(method == c("all", "efourier"))) {
     # efourier
-    dxy <- coo_dxy(coo)
-    plot(NA, xlim = c(1, nrow(coo)), ylim = c(range(unlist(dxy))),
+    d <- coo_dxy(coo)
+    plot(NA, xlim = c(1, nrow(coo)), ylim = c(range(unlist(d))),
          main = "Elliptical analysis", xlab = "Points along the outline",
-         ylab = "Deviation from the first point (pixels)")
-    lines(dxy$dx, col = "red")
-    text(sampled, dxy$dx[sampled], labels = labels, col = "red",
+         ylab = "Deviation from the first point")
+    lines(d$dx, col = "red")
+    text(sampled, d$dx[sampled], labels = labels, col = "red",
          cex = 0.7, font = 2)
-    lines(dxy$dy, col = "blue")
-    text(sampled, dxy$dy[sampled], labels = labels, col = "blue",
+    lines(d$dy, col = "blue")
+    text(sampled, d$dy[sampled], labels = labels, col = "blue",
          cex = 0.7, font = 2)
     legend("bottomright", legend = c(expression(x[i] - x[0]),
                                      expression(y[i] - y[0])), col = c("red", "blue"),
@@ -770,26 +764,27 @@ coo_oscillo <- function(coo, method = c("efourier", "rfourier",
 
   if (any(method == c("all", "rfourier"))) {
     # rfourier
-    dr <- coo_centdist(coo)
-    plot(NA, xlim = c(1, nrow(coo)), ylim = range(dr), main = "Radius variation",
+    d <- coo_centdist(coo)
+    plot(NA, xlim = c(1, nrow(coo)), ylim = range(d), main = "Radius variation",
          xlab = "Points along the outline", ylab = "Radius length (pixels)")
-    lines(dr, col = "black")
-    text(sampled, dr[sampled], labels = labels, col = "black",
+    lines(d, col = "black")
+    text(sampled, d[sampled], labels = labels, col = "black",
          cex = 0.7, font = 2)
   }
   # tfourier
   if (any(method == c("all", "tfourier"))) {
-    dt <- coo_tangle(coo)
-    plot(NA, xlim = c(1, nrow(coo)), ylim = range(dt), main = "Tangent angle",
+    d <- coo_angle_tangent(coo)
+    plot(NA, xlim = c(1, nrow(coo)), ylim = range(d), main = "Tangent angle",
          xlab = "Points along the outline", ylab = "Tangent angle (radians)")
-    # lines((1:nrow(coo))[sampled], dt[sampled], lty=2,
+    # lines((1:nrow(coo))[sampled], d[sampled], lty=2,
     # col='black')
-    lines(dt, col = "black")
-    text(sampled, dt[sampled], labels = labels, col = "black",
+    lines(d, col = "black")
+    text(sampled, d[sampled], labels = labels, col = "black",
          cex = 0.7, font = 2)
   }
   # we restore the layout
   layout(matrix(1))
+  return(d)
 }
 
 #' Ptolemaic ellipses and illustration of efourier
@@ -814,7 +809,6 @@ coo_oscillo <- function(coo, method = c("efourier", "rfourier",
 #' @seealso An intuitive explanation of elliptic Fourier analysis can be found in
 #' the \bold{Details} section of the \link{efourier} function.
 #' @examples
-#' data(shapes)
 #' cat <- shapes[4]
 #' Ptolemy(cat, main="An EFT cat")
 #' @seealso exemplifying functions
