@@ -2,16 +2,17 @@
 
 #' Linear Discriminant Analysis on Coe objects
 #'
-#' Performs a LDA on Coe objects. Relies on \link{lda} in MASS.
+#' Calculates a LDA on [Coe] on top of [MASS::lda].
+#'
 #' @aliases LDA
 #' @rdname LDA
 #' @param x a  PCA object
 #' @param fac the grouping factor (names of one of the $fac column or column id)
 #' @param retain the proportion of the total variance to retain (if retain<1) using \link{scree}, or the number of PC axis (if retain>1).
-#' @param verbose logical whether to print messages
 #' @param ... additional arguments to feed \link{lda}
 #' @note For LDA.PCA, retain can be passed as a vector (eg: 1:5, and retain=1, retain=2, ...,
 #' retain=5) will be tried, or as "best" (same as before but retain=1:number_of_pc_axes is used).
+#' @note Silent message and progress bars (if any) with `options("verbose"=FALSE)`.
 #' @return a 'LDA' object on which to apply \link{plot.LDA}, which is a list with components:
 #' \itemize{
 #'  \item \code{x} any \link{Coe} object (or a matrix)
@@ -29,7 +30,6 @@
 #' }
 #' @family multivariate
 #' @examples
-#' data(bot)
 #' bot.f <- efourier(bot, 24)
 #' bot.p <- PCA(bot.f)
 #' LDA(bot.p, 'type', retain=0.99) # retains 0.99 of the total variance
@@ -88,61 +88,40 @@ LDA.default <- function(x, fac, retain, ...) {
 #' @export
 LDA.OutCoe <- function(x, fac, retain, ...) {
   #  stop("LDA on other Coe than OutCoe is deprecated, try on a PCA object")
-  LDA(x$coe, x$fac[, fac])
+  LDA(x$coe, fac_dispatcher(x, fac))
 }
 
 #' @export
 LDA.Coe <- function(x, fac, retain, ...) {
-  stop("LDA on other Coe than OutCoe is deprecated, try on a PCA object")
-  # LDA(x$coe, x$fac[, fac])
+  # stop("LDA on other Coe than OutCoe is deprecated, try on a PCA object")
+  LDA(x$coe, fac_dispatcher(x, fac))
 }
 
 #' @rdname LDA
 #' @export
-LDA.PCA <- function(x, fac, retain = 0.99, verbose=TRUE, ...) {
+LDA.PCA <- function(x, fac, retain = 0.99, ...) {
 
-  if (length(retain)==1) {
-    if (retain=="best")
+  if (length(retain)==1 && retain < 1)
+      retain <- scree_min(x, retain)
+  if (length(retain)==1 && retain == "best")
     retain <- 1:ncol(x$x)
-  }
+
   # select best case
   if (length(retain)>1){
     discri <- numeric(length(retain))
     names(discri) <- paste0("PC1:", retain)
     for (i in seq_along(discri)){
-      discri[i] <- LDA(x=x, fac=fac, retain = retain[i], verbose=FALSE)$CV.correct
+      discri[i] <- LDA(x=x, fac=fac, retain = retain[i])$CV.correct
     }
     return(discri)
   }
 
   PCA <- x
-  f0 <- fac #<- prepare_fac(x, fac)
+  f0 <- fac
   #fac handling
-  if (missing(fac))
-    stop("no 'fac' provided")
-  # formula case
-  if (class(fac)=="formula"){
-    fform <- x$fac[, attr(terms(fac), "term.labels")]
-    fac <- interaction(fform)
-  }
+  fac <- fac_dispatcher(x, fac)
 
-  # case where fac is a standalone factor
-  if (is.factor(fac)) {
-    fac <- factor(fac)
-  }
-  # case where an id or column name is provided
-  if (!is.factor(fac)){
-    fac <- x$fac[, fac]
-  }
-
-  # PC number selection
-  if (retain <= 1)  {
-    if (verbose) message(retain, " total variance")
-    retain <- scree_min(x, prop = retain)
-  }
-
-
-  if (verbose) message(retain, " PC retained")
+  if (.is_verbose()) message(retain, " PC retained")
   X <- PCA$x[, 1:retain]
   if (is.matrix(X)) {
     remove <- which(apply(X, 2, sd) < 1e-10)
@@ -155,7 +134,7 @@ LDA.PCA <- function(x, fac, retain = 0.99, verbose=TRUE, ...) {
   }
   X <- as.matrix(X)
   # now we calculate two lda models with MASS::lda one with
-  mod <- MASS::lda(X, grouping = fac, tol = 1e-08, ...)
+  mod <- MASS::lda(X, grouping=fac, tol = 1e-08, ...)
   mod.pred <- predict(mod, X)
   # leave-one-out cross validation
   CV.fac <- MASS::lda(X, grouping = fac, tol = 1e-08, CV = TRUE, ...)$class
@@ -189,16 +168,17 @@ LDA.PCA <- function(x, fac, retain = 0.99, verbose=TRUE, ...) {
 
 #' @export
 print.LDA <- function(x, ...) {
-  cat(" * Leave-one-out cross-validation ($CV.correct): (",
-      signif(x$CV.correct * 100, 3), "% - ",
-      sum(diag(x$CV.tab)), "/", sum(x$CV.tab),
-      "): \n", sep = "")
+
+  cat(" * Cross-validation table ($CV.tab):\n")
+  print(x$CV.tab)
 
   cat("\n * Class correctness ($CV.ce):\n")
   print(x$CV.ce)
 
-  cat("\n * Cross-validation table ($CV.tab):\n")
-  print(x$CV.tab)
+  cat("\n * Leave-one-out cross-validation ($CV.correct): (",
+      signif(x$CV.correct * 100, 3), "% - ",
+      sum(diag(x$CV.tab)), "/", sum(x$CV.tab),
+      "): \n", sep = "")
 
 }
 
@@ -263,10 +243,10 @@ classification_metrics.table <- function(x){
   precision <- diag / colsums
   recall <- diag / rowsums
   f1 <- 2 * precision * recall / (precision + recall)
-  macro_prf <- data.frame(precision, recall, f1)
+  macro_prf <- dplyr::data_frame(precision, recall, f1)
 
   # macro precision, recall, f1
-  macro_avg <- data.frame(avg_precision=mean(precision),
+  macro_avg <- dplyr::data_frame(avg_precision=mean(precision),
                           avg_recall=mean(recall),
                           avg_f1=mean(f1))
 
@@ -288,7 +268,7 @@ classification_metrics.table <- function(x){
   # we add all these matrices
   ova_sum <- Reduce("+", ova)
   dimnames(ova_sum) %<>% lapply(`[<-`, 1, "relevant")
-  # micro <- data.frame(accuracy=sum(diag(ova_sum)) / sum(ova_sum),
+  # micro <- dplyr::data_frame(accuracy=sum(diag(ova_sum)) / sum(ova_sum),
   # prf=(diag(ova_sum) / apply(ova_sum, 1, sum))[1])
 
   expAccuracy = sum(p*q)
@@ -309,90 +289,89 @@ classification_metrics.LDA <- function(x){
 }
 
 # classify --------
-#' Classify using LDA
-#'
-#' @param x a Coe
-#' @param fac a standalone factor, or the name or id of the $fac column to use.If it contains
-#' NAs, they will also be removed first from the x object
-#' @param ref at least two level names from $fac[, "fac"] to use as a training subset of x
-#' @param unk same as above for one level name to classify
-#'
-#' @return a list with components:
-#' \itemize{
-#' \item \code{$N_ref} the number of elements in the training set
-#' \item \code{$N_unk} the number of elements in the unknown set
-#' \item \code{$counts} counts of classification of 'unk' in each class of 'ref'
-#' \item \code{$pc} same thing as percentages
-#' \item \code{$probs} same thing as posterior probabilities
-#' \item \code{$probs} same thing as posterior but as a data.frame
-#' }
-#'
-#' @examples
-#' data(olea)
-#' table(olea, "var")
-#' x <- opoly(olea, 5, verbose=FALSE)
-#' classify(x, fac="var", ref=c("Aglan","Cypre"), unk="PicMa")
-#' @export
-classify <- function(x, fac, ref, unk){
-  UseMethod("classify")
-}
-#' @export
-classify.default <- function(x, fac, ref, unk){
-  stop("method only available for objects of class 'Coe'")
-}
-
-#' @export
-classify.Coe <- function(x, fac, ref, unk){
-  # so that we can directly pass a fac
-  if (!is.factor(fac)){
-    fac <- x$fac[, fac]
-  }
-  # fac <- prepare_fac(x, fac)
-  # if any NAs, we remove them
-  if (any(is.na(fac))) {
-    x  <- x %>% subset(which(!is.na(fac)))
-    fac <- fac %>% na.omit() %>% factor()
-  }
-  # we filter for levels of interest
-  all_id  <- which(fac %in% c(ref, unk))
-  # cat(all_id)
-  x <- subset(x, all_id)
-  fac <- fac[all_id]
-  # calculate a PCA using all taxa
-  P0 <- PCA(x)
-  # calculate an LDA using all but the unknown taxa
-  ref_id <- which(fac != unk)
-  L0 <- P0 %>%
-    subset(ref_id) %>%
-    LDA(fac[ref_id], retain=0.99, verbose=FALSE)
-  # extract and prepare scores of the unknown taxa
-  unk_id <- which(fac == unk)
-  P1_all <- P0 %>%
-    subset(unk_id)
-  P1 <- P1_all$x[, 1:ncol(L0$x)]
-
-  # classify using the MASS::lda
-  pred <- predict(L0$mod, P1)
-  # prepare the results as a list
-  counts <- table(pred$class)
-  N_unk  <- sum(counts)
-  pc     <- round((counts / sum(counts))*100, 2)
-  probs  <- pred$posterior
-#
-#   probs_fac <- cbind(pred$posterior, select(P1_all$fac, Site, Period)) %>%
-#     group_by(Site, Period) %>%
-#     summarise_each(funs(mean))
-#   probs_fac <- bind_cols(select(probs_fac, 1:2), round(select(probs_fac, 3)))
-  probs_fac <- NULL
-
-  return(list(N_ref=nrow(L0$x),
-              N_ref_tab=table(L0$fac),
-              N_unk=N_unk,
-              counts=counts,
-              pc=pc,
-              probs=probs,
-              probs_fac=probs_fac))
-}
+# #' Classify using LDA
+# #'
+# #' @param x a Coe
+# #' @param fac a standalone factor, or the name or id of the $fac column to use.If it contains
+# #' NAs, they will also be removed first from the x object
+# #' @param ref at least two level names from `$fac` to use as a training subset of x
+# #' @param unk same as above for one level name to classify
+# #'
+# #' @return a list with components:
+# #' \itemize{
+# #' \item \code{$N_ref} the number of elements in the training set
+# #' \item \code{$N_unk} the number of elements in the unknown set
+# #' \item \code{$counts} counts of classification of 'unk' in each class of 'ref'
+# #' \item \code{$pc} same thing as percentages
+# #' \item \code{$probs} same thing as posterior probabilities
+# #' \item \code{$probs} same thing as posterior but as a data.frame
+# #' }
+# #'
+# #' @examples
+# #' table(olea$var)
+# #' x <- opoly(olea, 5)
+# #' classify(x, fac="var", ref=c("Aglan","Cypre"), unk="PicMa")
+# #' @export
+# #' classify <- function(x, fac, ref, unk){
+# #'   UseMethod("classify")
+# #' }
+# #' @export
+# #' classify.default <- function(x, fac, ref, unk){
+# #'   stop("method only available for objects of class 'Coe'")
+# #' }
+# #'
+# #' @export
+# #' classify.Coe <- function(x, fac, ref, unk){
+# #'   # so that we can directly pass a fac
+# #'   if (!is.factor(fac)){
+# #'     fac <- x$fac[, fac]
+# #'   }
+# #'   # fac <- fac_dispatcher(x, fac)
+# #'   # if any NAs, we remove them
+# #'   if (any(is.na(fac))) {
+# #'     x  <- x %>% slice(which(!is.na(fac)))
+# #'     fac <- fac %>% na.omit() %>% factor()
+# #'   }
+# #'   # we filter for levels of interest
+# #'   all_id  <- (fac %in% c(ref, unk))
+# #'   # cat(all_id)
+# #'   x <- slice(x, all_id)
+# #'   fac <- fac[all_id]
+# #'   # calculate a PCA using all taxa
+# #'   P0 <- PCA(x)
+# #'   # calculate an LDA using all but the unknown taxa
+# #'   ref_id <- fac != unk
+# #'   L0 <- P0 %>%
+# #'     slice(ref_id) %>%
+# #'     LDA(fac[ref_id], retain=0.99)
+# #'   # extract and prepare scores of the unknown taxa
+# #'   unk_id <- fac == unk
+# #'   P1_all <- P0 %>%
+# #'     slice(unk_id)
+# #'   P1 <- P1_all$x[, 1:ncol(L0$x)]
+# #'
+# #'   # classify using the MASS::lda
+# #'   pred <- predict(L0$mod, P1)
+# #'   # prepare the results as a list
+# #'   counts <- table(pred$class)
+# #'   N_unk  <- sum(counts)
+# #'   pc     <- round((counts / sum(counts))*100, 2)
+# #'   probs  <- pred$posterior
+# #' #
+# #' #   probs_fac <- cbind(pred$posterior, select(P1_all$fac, Site, Period)) %>%
+# #' #     group_by(Site, Period) %>%
+# #' #     summarise_each(funs(mean))
+# #' #   probs_fac <- dplyr::bind_cols(dplyr::select(probs_fac, 1:2), round(select(probs_fac, 3)))
+# #'   probs_fac <- NULL
+# #'
+# #'   return(list(N_ref=nrow(L0$x),
+# #'               N_ref_tab=table(L0$fac),
+# #'               N_unk=N_unk,
+# #'               counts=counts,
+# #'               pc=pc,
+# #'               probs=probs,
+# #'               probs_fac=probs_fac))
+# #' }
 
 # reLDA -----------
 
@@ -413,9 +392,8 @@ classify.Coe <- function(x, fac, ref, unk){
 #' \item newdata the data used to calculate passed to predict.lda
 #' }
 #' @note Uses the same number of PC axis as the LDA object provided. You should probably use \link{rePCA} in
-#' conjonction with reLDA to get 'homologous' scores.
+#' conjunction with reLDA to get 'homologous' scores.
 #' @examples
-#' data(bot)
 #' # We select the first 10 individuals in bot,
 #' # for whisky and beer bottles. It will be our referential.
 #' bot1   <- slice(bot, c(1:10, 21:30))
@@ -463,7 +441,7 @@ reLDA.PCA <- function(newdata, LDA){
   #   if (length(LDA$f0)==1) {
   #     actual <- newdata$fac[, LDA$f0]
   #     if (!is.null(actual)) {
-  #       reLDA$res <- data.frame(actual=actual, classified=reLDA$class)
+  #       reLDA$res <- dplyr::data_frame(actual=actual, classified=reLDA$class)
   #       reLDA$CV.tab <- table(reLDA$res)
   #       reLDA$CV.correct <- sum(diag(reLDA$CV.tab)) / sum(reLDA$CV.tab)
   #     }
