@@ -7,30 +7,30 @@ test_that("Coo works fine", {
   # Coo constructor doesnt exist alone
   expect_message(Coo())
   expect_message(Coo(bot$coo))
-  expect_true(x %>% is.Coo())
-  expect_true(x %>% Opn() %>% validate %>% is.Coo())
-  expect_true(x %>% Ldk() %>% validate %>% is.Coo())
+  expect_true(x %>% is_Coo())
+  expect_true(x %>% Opn() %>% validate %>% is_Coo())
+  expect_true(x %>% Ldk() %>% validate %>% is_Coo())
 })
 
 test_that("Out works fine", {
-  expect_true(x %>% validate %>% is.Out())
-  expect_true(x[1] %>% is.shp())
+  expect_true(x %>% validate %>% is_Out())
+  expect_true(x[1] %>% is_shp())
   expect_true(x[1] %>% is.matrix)
   expect_true(x[1:2] %>% is.list)
 })
 
 test_that("Opn works fine", {
   x <- Opn(x)
-  expect_true(x %>% validate %>% is.Opn())
-  expect_true(x[1] %>% is.shp())
+  expect_true(x %>% validate %>% is_Opn())
+  expect_true(x[1] %>% is_shp())
   expect_true(x[1] %>% is.matrix)
   expect_true(x[1:2] %>% is.list)
 })
 
 test_that("Ldk works fine", {
   x <- Ldk(x)
-  expect_true(x %>% validate %>% is.Ldk())
-  expect_true(x[1] %>% is.shp())
+  expect_true(x %>% validate %>% is_Ldk())
+  expect_true(x[1] %>% is_shp())
   expect_true(x[1] %>% is.matrix)
   expect_true(x[1:2] %>% is.list)
 })
